#[repr(i32)]pub enum Direction {
Ascending = 0,
Descending = 1,
}Expand description
Block enumeration direction.
Variants
Ascending = 0
Enumerate in ascending order (from child to parent).
Descending = 1
Enumerate in descending order (from parent to canonical child).
Implementations
Sourceimpl Direction
impl Direction
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.